@@ -4,7 +4,7 @@ use strict;
 use warnings;
 
 use vars qw($VERSION);
-$VERSION = '0.02';
+$VERSION = '0.03';
 
 #----------------------------------------------------------------------------
 
@@ -24,12 +24,12 @@ my %map = (
     'svr4'      => 'Linux',
     'unicos'    => 'Linux',
     'unicosmk'  => 'Linux',
-    'solaris'   => 'Linux',
     'sunos'     => 'Linux',
     'ultrix'    => 'Linux',
     'sco_sv'    => 'SCO',
     'sco3'      => 'SCO',
     'sco'       => 'SCO',
+    'solaris'   => 'Solaris',
 
     # Windows family OSes
     'dos'       => 'Win32',
@@ -151,6 +151,12 @@ to the specific operating system.
 
 =back
 
+=head1 REFERENCES
+
+The following links were used to understand how to retrieve the metadata:
+
+  * http://alma.ch/perl/perloses.htm
+
 =head1 BUGS, PATCHES & FIXES
 
 There are no known bugs at the time of this release. However, if you spot a
